@@ -14,7 +14,7 @@ log = logging.getLogger(__name__)
 THEME_BASE_DIR = os.path.dirname(os.path.realpath(__file__))
 PATHS = [
     ".",
-    os.path.join(THEME_BASE_DIR, "../../themes")
+    os.path.join(THEME_BASE_DIR, "../../themes"),
 ]
 
 if os.environ.get("XDG_DATA_DIRS"):
@@ -26,6 +26,8 @@ PATHS.extend([
     os.path.expanduser("~/.config/bumblebee-status/themes"),
     os.path.expanduser("~/.local/share/bumblebee-status/themes"),  # PIP
     os.path.expanduser("~/.local/pipx/venvs/bumblebee-status/share/bumblebee-status/themes"),  # PIPX
+    os.path.expanduser("~/.local/share/pipx/venvs/bumblebee-status/share/bumblebee-status/themes"), # PIPX, part 2
+    os.path.expanduser("~/.local/share/uv/tools/bumblebee-status/share/bumblebee-status/themes/"), # uv
     "/usr/share/bumblebee-status/themes",
 ])
 
