@@ -279,6 +279,12 @@ try:
     import configparser
 except ImportError:
     import ConfigParser as configparser
+
+try:
+    from configparser import SafeConfigParser as ConfigParser
+except ImportError:
+    from configparser import ConfigParser
+
 import errno
 import json
 import os
@@ -341,9 +347,12 @@ def get_config_from_root(root):
     # configparser.NoOptionError (if it lacks "VCS="). See the docstring at
     # the top of versioneer.py for instructions on writing your setup.cfg .
     setup_cfg = os.path.join(root, "setup.cfg")
-    parser = configparser.SafeConfigParser()
+    parser = ConfigParser()
     with open(setup_cfg, "r") as f:
-        parser.readfp(f)
+        try:
+            parser.readfp(f)
+        except AttributeError:
+            parser.read_file(f)
     VCS = parser.get("versioneer", "VCS")  # mandatory
 
     def get(parser, name):
